@@ -100,9 +100,10 @@ if [ -f noaddendum ]; then
 	-f man \
 	--option groff_code=verbatim \
 	--option generated \
-	--option untranslated="}1,Ds,zY,zZ,Ee,ES,dT,FN,NE,NS,EX,EE,Id,rstReportMargin,INDENT,UNINDENT,UN,a.RE,\|" \
+	--option untranslated="}1,Ds,zY,zZ,Ee,ES,dT,FN,NE,NS,EX,EE,Id,rstReportMargin,INDENT,UNINDENT,UN,a.RE,\|,Vb,Ve" \
 	--option unknown_macros=untranslated \
 	--option inline="MR" \
+	--option no_wrap="Vb:Ve" \
 	-m "$tdir/$distribution/$manname" \
 	-M "utf-8" \
 	-p "$pofile" \
@@ -113,9 +114,10 @@ else
 	-f man \
 	--option groff_code=verbatim \
 	--option generated \
-	--option untranslated="}1,Ds,zY,zZ,Ee,ES,dT,NE,NS,EX,EE,Id,rstReportMargin,INDENT,UNINDENT,UN,a.RE,\|" \
+	--option untranslated="}1,Ds,zY,zZ,Ee,ES,dT,NE,NS,EX,EE,Id,rstReportMargin,INDENT,UNINDENT,UN,a.RE,\|,Vb,Ve" \
 	--option unknown_macros=untranslated \
 	--option inline="MR" \
+	--option no_wrap="Vb:Ve" \
 	-m "$tdir/$distribution/$manname" \
 	-M "utf-8" \
 	-p "$pofile" \
